ListPropertyUpdate

Trait ListPropertyUpdate 

pub trait ListPropertyUpdate<S: ?Sized>: ListPropertyInit {
    type ItemValue: ?Sized;

    // Required method
    fn compare_and_set_item_ref<U: ListPropertyItem<Self, S, Value = Self::ItemValue>>(
        dest: &mut Self,
        index: usize,
        src: &S,
        ctx: &mut Self::UpdateContext,
    )
       where Self: Sized;
}
The list property updater.

This trait is implemented by ListProp . Custom event types that implements this trait can also be used in templates with :xxx= syntax.

Required Associated Types

type ItemValue: ?Sized

The item value type.

Must match the corresponding ListPropertyItem::Value .

Required Methods

fn compare_and_set_item_ref<U: ListPropertyItem<Self, S, Value = Self::ItemValue>>( dest: &mut Self, index: usize, src: &S, ctx: &mut Self::UpdateContext, )
where Self: Sized,

The updater.

If used in components and updated through templates, ctx must be set to true if updated.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors